# generativepy

Generative art and graphing library for creating images and animations.

## Usage

generativepy is a library, not an application. It provides useful functions that allow you to create images and videos by writing simple Python scripts.

The library uses [pycairo](https://pycairo.readthedocs.io/en/latest/index.html) for drawing graphics.

Main functionality:

* A simple framework for creating images and image sequences using pycairo.
* Colour module that supports RGB, HSL and CSS colours and conversion, and transparency support.
* A simple tweening module to help with animation.
* Geometry module for drawings shapes.
* A graphing library for plotting 2D functions.

## Website

Visit [tenminutetutor.com](http://www.tenminutetutor.com/generative-art/generativepy/) for details.

For detailed information of pycairo see the [Computer graphics in Python](https://leanpub.com/computergraphicsinpython) ebook.
